@@ -12,10 +12,11 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
+import os
 import re
 import logging
 
-__version__ = '0.35.0'
+__version__ = '0.36.0'
 
 
 class NullHandler(logging.Handler):
@@ -46,6 +47,8 @@ _xform_cache = {
 }
 ScalarTypes = ('string', 'integer', 'boolean', 'timestamp', 'float', 'double')
 
+BOTOCORE_ROOT = os.path.dirname(os.path.abspath(__file__))
+
 
 def xform_name(name, sep='_', _xform_cache=_xform_cache):
     """
